@@ -287,7 +287,7 @@ enum css_column_gap_e {
 enum css_column_rule_color_e {
 	CSS_COLUMN_RULE_COLOR_INHERIT		= CSS_BACKGROUND_COLOR_INHERIT,
 	CSS_COLUMN_RULE_COLOR_COLOR		= CSS_BACKGROUND_COLOR_COLOR,
-	CSS_COLUMN_RULE_COLOR_CURRENT_COLOR	= CSS_BACKGROUND_COLOR_CURRENT_COLOR,
+	CSS_COLUMN_RULE_COLOR_CURRENT_COLOR	= CSS_BACKGROUND_COLOR_CURRENT_COLOR
 };
 
 enum css_column_rule_style_e {
@@ -585,6 +585,11 @@ enum css_overflow_e {
 	CSS_OVERFLOW_AUTO			= 0x4
 };
 
+enum css_orphans_e {
+	CSS_ORPHANS_INHERIT			= 0x0,
+	CSS_ORPHANS_SET				= 0x1
+};
+
 enum css_padding_e {
 	CSS_PADDING_INHERIT			= 0x0,
 	CSS_PADDING_SET				= 0x1
@@ -718,6 +723,11 @@ enum css_white_space_e {
 	CSS_WHITE_SPACE_PRE_LINE		= 0x5
 };
 
+enum css_widows_e {
+	CSS_WIDOWS_INHERIT			= 0x0,
+	CSS_WIDOWS_SET				= 0x1
+};	
+	
 enum css_width_e {
 	CSS_WIDTH_INHERIT			= 0x0,
 	CSS_WIDTH_SET				= 0x1,
